@@ -1,11 +1,11 @@
-require 'rexml/document'
+require 'redmine/scm/adapters/subversion_adapter'
 
 module Redmine
   # @private
   module VERSION
     MAJOR = 4
     MINOR = 0
-    TINY  = 4
+    TINY  = 5
 
     # Branch values:
     # * official release: nil
